@@ -291,7 +291,7 @@ typedef struct {
 }  zlist_t;
 
 zlist_t * zlist_new(int count);                                                  //  create zlist with 'count' empty members
-void zlist_delete(zlist_t *zlist);                                               //  delete a zlist
+void zlist_free(zlist_t *zlist);                                                 //  delete zlist, free memory
 void zlist_dump(zlist_t *zlist);                                                 //  dump zlist to stdout
 int zlist_count(zlist_t *zlist);                                                 //  get zlist member count
 ch * zlist_get(zlist_t *zlist, int Nth);                                         //  get a zlist member
